==> spice-gtk-0.5.tar.bz2: spice-gtk-0.5/gtk/spice-marshal.h <==

#ifndef __g_cclosure_user_marshal_MARSHAL_H__
#define __g_cclosure_user_marshal_MARSHAL_H__

#include	<glib-object.h>

G_BEGIN_DECLS

/* VOID:INT,INT (spice-marshal.txt:1) */
extern void g_cclosure_user_marshal_VOID__INT_INT (GClosure     *closure,
                                                   GValue       *return_value,
                                                   guint         n_param_values,
                                                   const GValue *param_values,
                                                   gpointer      invocation_hint,
                                                   gpointer      marshal_data);

/* VOID:INT,INT,INT (spice-marshal.txt:2) */
extern void g_cclosure_user_marshal_VOID__INT_INT_INT (GClosure     *closure,
                                                       GValue       *return_value,
                                                       guint         n_param_values,
                                                       const GValue *param_values,
                                                       gpointer      invocation_hint,
                                                       gpointer      marshal_data);

/* VOID:INT,INT,INT,INT (spice-marshal.txt:3) */
extern void g_cclosure_user_marshal_VOID__INT_INT_INT_INT (GClosure     *closure,
                                                           GValue       *return_value,
                                                           guint         n_param_values,
                                                           const GValue *param_values,
                                                           gpointer      invocation_hint,
                                                           gpointer      marshal_data);

/* VOID:INT,INT,INT,INT,POINTER (spice-marshal.txt:4) */
extern void g_cclosure_user_marshal_VOID__INT_INT_INT_INT_POINTER (GClosure     *closure,
                                                                   GValue       *return_value,
                                                                   guint         n_param_values,
                                                                   const GValue *param_values,
                                                                   gpointer      invocation_hint,
                                                                   gpointer      marshal_data);

/* VOID:INT,INT,INT,INT,INT,POINTER (spice-marshal.txt:5) */
extern void g_cclosure_user_marshal_VOID__INT_INT_INT_INT_INT_POINTER (GClosure     *closure,
                                                                       GValue       *return_value,
                                                                       guint         n_param_values,
                                                                       const GValue *param_values,
                                                                       gpointer      invocation_hint,
                                                                       gpointer      marshal_data);

/* VOID:POINTER,INT (spice-marshal.txt:6) */
extern void g_cclosure_user_marshal_VOID__POINTER_INT (GClosure     *closure,
                                                       GValue       *return_value,
                                                       guint         n_param_values,
                                                       const GValue *param_values,
                                                       gpointer      invocation_hint,
                                                       gpointer      marshal_data);

/* BOOLEAN:POINTER,UINT (spice-marshal.txt:7) */
extern void g_cclosure_user_marshal_BOOLEAN__POINTER_UINT (GClosure     *closure,
                                                           GValue       *return_value,
                                                           guint         n_param_values,
                                                           const GValue *param_values,
                                                           gpointer      invocation_hint,
                                                           gpointer      marshal_data);

/* BOOLEAN:UINT (spice-marshal.txt:8) */
extern void g_cclosure_user_marshal_BOOLEAN__UINT (GClosure     *closure,
                                                   GValue       *return_value,
                                                   guint         n_param_values,
                                                   const GValue *param_values,
                                                   gpointer      invocation_hint,
                                                   gpointer      marshal_data);

/* VOID:UINT,POINTER,UINT (spice-marshal.txt:9) */
extern void g_cclosure_user_marshal_VOID__UINT_POINTER_UINT (GClosure     *closure,
                                                             GValue       *return_value,
                                                             guint         n_param_values,
                                                             const GValue *param_values,
                                                             gpointer      invocation_hint,
                                                             gpointer      marshal_data);

G_END_DECLS

#endif /* __g_cclosure_user_marshal_MARSHAL_H__ */

==> spice-gtk_0.7.orig.tar.bz2: spice-gtk-0.7/gtk/spice-marshal.h <==

#ifndef __g_cclosure_user_marshal_MARSHAL_H__
#define __g_cclosure_user_marshal_MARSHAL_H__

#include	<glib-object.h>

G_BEGIN_DECLS

/* VOID:INT,INT (spice-marshal.txt:1) */
extern void g_cclosure_user_marshal_VOID__INT_INT (GClosure     *closure,
                                                   GValue       *return_value,
                                                   guint         n_param_values,
                                                   const GValue *param_values,
                                                   gpointer      invocation_hint,
                                                   gpointer      marshal_data);

/* VOID:INT,INT,INT (spice-marshal.txt:2) */
extern void g_cclosure_user_marshal_VOID__INT_INT_INT (GClosure     *closure,
                                                       GValue       *return_value,
                                                       guint         n_param_values,
                                                       const GValue *param_values,
                                                       gpointer      invocation_hint,
                                                       gpointer      marshal_data);

/* VOID:INT,INT,INT,INT (spice-marshal.txt:3) */
extern void g_cclosure_user_marshal_VOID__INT_INT_INT_INT (GClosure     *closure,
                                                           GValue       *return_value,
                                                           guint         n_param_values,
                                                           const GValue *param_values,
                                                           gpointer      invocation_hint,
                                                           gpointer      marshal_data);

/* VOID:INT,INT,INT,INT,POINTER (spice-marshal.txt:4) */
extern void g_cclosure_user_marshal_VOID__INT_INT_INT_INT_POINTER (GClosure     *closure,
                                                                   GValue       *return_value,
                                                                   guint         n_param_values,
                                                                   const GValue *param_values,
                                                                   gpointer      invocation_hint,
                                                                   gpointer      marshal_data);

/* VOID:INT,INT,INT,INT,INT,POINTER (spice-marshal.txt:5) */
extern void g_cclosure_user_marshal_VOID__INT_INT_INT_INT_INT_POINTER (GClosure     *closure,
                                                                       GValue       *return_value,
                                                                       guint         n_param_values,
                                                                       const GValue *param_values,
                                                                       gpointer      invocation_hint,
                                                                       gpointer      marshal_data);

/* VOID:POINTER,INT (spice-marshal.txt:6) */
extern void g_cclosure_user_marshal_VOID__POINTER_INT (GClosure     *closure,
                                                       GValue       *return_value,
                                                       guint         n_param_values,
                                                       const GValue *param_values,
                                                       gpointer      invocation_hint,
                                                       gpointer      marshal_data);

/* BOOLEAN:POINTER,UINT (spice-marshal.txt:7) */
extern void g_cclosure_user_marshal_BOOLEAN__POINTER_UINT (GClosure     *closure,
                                                           GValue       *return_value,
                                                           guint         n_param_values,
                                                           const GValue *param_values,
                                                           gpointer      invocation_hint,
                                                           gpointer      marshal_data);

/* BOOLEAN:UINT (spice-marshal.txt:8) */
extern void g_cclosure_user_marshal_BOOLEAN__UINT (GClosure     *closure,
                                                   GValue       *return_value,
                                                   guint         n_param_values,
                                                   const GValue *param_values,
                                                   gpointer      invocation_hint,
                                                   gpointer      marshal_data);

/* VOID:BOXED (spice-marshal.txt:9) */
#define g_cclosure_user_marshal_VOID__BOXED	g_cclosure_marshal_VOID__BOXED

/* VOID:UINT,POINTER,UINT (spice-marshal.txt:10) */
extern void g_cclosure_user_marshal_VOID__UINT_POINTER_UINT (GClosure     *closure,
                                                             GValue       *return_value,
                                                             guint         n_param_values,
                                                             const GValue *param_values,
                                                             gpointer      invocation_hint,
                                                             gpointer      marshal_data);

/* VOID:UINT,UINT,POINTER,UINT (spice-marshal.txt:11) */
extern void g_cclosure_user_marshal_VOID__UINT_UINT_POINTER_UINT (GClosure     *closure,
                                                                  GValue       *return_value,
                                                                  guint         n_param_values,
                                                                  const GValue *param_values,
                                                                  gpointer      invocation_hint,
                                                                  gpointer      marshal_data);

/* BOOLEAN:UINT,POINTER,UINT (spice-marshal.txt:12) */
extern void g_cclosure_user_marshal_BOOLEAN__UINT_POINTER_UINT (GClosure     *closure,
                                                                GValue       *return_value,
                                                                guint         n_param_values,
                                                                const GValue *param_values,
                                                                gpointer      invocation_hint,
                                                                gpointer      marshal_data);

/* BOOLEAN:UINT,UINT (spice-marshal.txt:13) */
extern void g_cclosure_user_marshal_BOOLEAN__UINT_UINT (GClosure     *closure,
                                                        GValue       *return_value,
                                                        guint         n_param_values,
                                                        const GValue *param_values,
                                                        gpointer      invocation_hint,
                                                        gpointer      marshal_data);

G_END_DECLS

#endif /* __g_cclosure_user_marshal_MARSHAL_H__ */
